/************************************************************************
     File:        window.cpp

     Author:     
                  Yu-Chi Lai, yu-chi@cs.wisc.edu
     
     Comment:     Demo for the use of FLTK in event handler and callback function
   
     Platform:    Visio Studio.Net 2003
*************************************************************************/

#include <iostream>
#include <FL/Fl.H>
#include <FL/Fl_Window.H>
#include <FL/Fl_Double_Window.H>
#include <FL/Fl_Value_Slider.H>
#include <FL/Fl_Button.H>

#include "EventBox.h"

Fl_Window*       win = NULL;     // The main window pointer
Fl_Button*       button = NULL;  // The button pointer
EventBox*        box = NULL;     // The pointer to the box
Fl_Value_Slider* slider = NULL;  // The pointer to the slider who will change label size

//****************************************************************************
//
// * The slider callback function
//=============================================================================
void Slider_Callback(Fl_Widget *w)
//=============================================================================
{
	int label_size = slider->value();
	box->labelsize(label_size);
	box->damage(1);
}

//****************************************************************************
//
// * The button callback function
//=============================================================================
void Button_Callback(Fl_Widget *w)
//=============================================================================
{
	static flag = true;
	if(true) {
		box->label("Bye");
		flag = false;
	}
	else {
		box->label("Hello");
		flag = true;
	}
	box->damage(1);
}

int main()
{
	// Set up the container window
	win = new Fl_Window(300, 300, "Example Window");

		// Put in our own widget
		box = new EventBox(40, 20, 220, 220);
		// make the box show up	
		box->show();

		// Put in Slider and text indicator
		// The time slider
		slider = new Fl_Value_Slider(5, 270, 200, 25);
		// Set up the type of the slider
		slider->type(FL_HOR_SLIDER);
		// Set up the boundary of the slider
		slider->bounds(1.0, 24.0);
		// Set up the default value
		slider->value(25.0);
		// Set up the callback function
		slider->callback(Slider_Callback);
		// Show up the slider
		slider->show();

		// put a button in
		button = new Fl_Button(220, 270, 75, 25, "Change");
		button->callback(Button_Callback);

	// The end of window component definition
	win->end();
	// make the window show up
	win->show();
	return Fl::run();

}